==> php83-nextcloud-26.0.5.tgz: share/nextcloud/apps/updatenotification/l10n/ca.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Hi ha disponible la versió {version}. Obteniu més informació sobre com aplicar l'actualització.",
    "Channel updated" : "S'ha actualitzat el canal",
    "Web updater is disabled" : "L'actualitzador web està inhabilitat",
    "Update notifications" : "Notificacions d'actualització",
    "The update server could not be reached since %d days to check for new updates." : "No s'ha pogut accedir al servidor d'actualitzacions des de fa %d dies per a comprovar si hi ha actualitzacions noves.",
    "Please check the Nextcloud and server log files for errors." : "Consulteu els fitxers de registre del servidor i del Nextcloud per a detectar errors.",
    "Update to %1$s is available." : "Hi ha disponible l'actualització a la versió %1$s.",
    "Update to {serverAndVersion} is available." : "Hi ha disponible l'actualització a {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Hi ha disponible l'actualització a la versió %s per a {app}.",
    "Update notification" : "Notificació d'actualització",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Mostra les notificacions d'actualització del Nextcloud i proporciona l'SSO de l'actualitzador.",
    "Update" : "Actualització",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versió que esteu executant ja no es manté. Assegureu-vos d’actualitzar com més aviat millor a una versió admesa.",
    "Apps missing compatible version" : "Aplicacions sense cap versió compatible",
    "View in store" : "Mostra-ho a la botiga",
    "Apps with compatible version" : "Aplicacions amb una versió compatible",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Tingueu en compte que no es recomana l'actualitzador web amb més de 100 usuaris. Utilitzeu l'actualitzador de la línia d'ordres.",
    "Open updater" : "Obre l'actualitzador",
    "Download now" : "Baixa-ho ara",
    "Please use the command line updater to update." : "Utilitzeu l'actualitzador de la línia d'ordres per a aplicar l'actualització.",
    "What's new?" : "Quines novetats hi ha?",
    "View changelog" : "Mostra el registre de canvis",
    "The update check is not yet finished. Please refresh the page." : "La comprovació d'actualitzacions encara no ha finalitzat. Actualitzeu la pàgina.",
    "Your version is up to date." : "Teniu la versió més recent.",
    "A non-default update server is in use to be checked for updates:" : "S'utilitza un servidor d'actualitzacions diferent del servidor per defecte per a comprovar si hi ha actualitzacions:",
    "Update channel" : "Canal d'actualitzacions",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Canviar de canal d'actualitzacions també afecta la pàgina d'administració d'aplicacions. Per exemple, després de canviar al canal beta, se us oferiran actualitzacions d'aplicacions beta a la pàgina d'administració d'aplicacions.",
    "Current update channel:" : "Canal d'actualitzacions actual:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre podeu actualitzar a una versió més recent, però no podeu tornar mai a una versió anterior més estable.",
    "Notify members of the following groups about available updates:" : "Notifica els membres dels grups següents sobre les actualitzacions disponibles:",
    "No groups" : "No hi ha cap grup",
    "Only notifications for app updates are available." : "Només hi ha disponibles notificacions per a actualitzacions d'aplicacions.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal d'actualitzacions seleccionat deixa obsoletes les notificacions específiques del servidor.",
    "The selected update channel does not support updates of the server." : "El canal d'actualitzacions seleccionat no admet les actualitzacions del servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hi ha disponible una nova versió: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Tingueu en compte que, després d'una versió nova, només es mostrarà l'actualització després de la primera versió menor o més endavant. Distribuïm les versions noves de manera repartida en el temps als nostres usuaris i, de vegades, ometem una versió si hi trobem problemes. Obteniu més informació sobre les actualitzacions i els canals de versions a {link}",
    "Checked on {lastCheckedDate}" : "Darrera comprovació: {lastCheckedDate}",
    "Checking apps for compatible versions" : "S'està comprovant si hi ha versions compatibles de les aplicacions",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Assegureu-vos que el fitxer config.php no defineixi <samp>appstoreenabled</samp> com a fals.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No s'ha pogut establir la connexió a la botiga d'aplicacions o no s'ha retornat cap actualització. Cerqueu les actualitzacions manualment o assegureu-vos que el servidor tingui accés a Internet i que es pugui connectar a la botiga d'aplicacions.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Totes</strong> les aplicacions tenen una versió compatible amb aquesta versió del Nextcloud.",
    "Enterprise" : "Empresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Per a ús empresarial. Proporciona sempre els pedaços més recents, però no s'actualitzarà immediatament a la versió principal següent. Aquesta actualització es produeix quan Nextcloud GmbH ha fet proves i millores addicionals per a implementacions a gran escala i crítiques. Aquest canal només està disponible per als clients i proporciona el paquet Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versió estable més recent. És adequada per a un ús normal i sempre s'actualitzarà a la versió principal més recent.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versió preliminar només per a provar característiques noves, no per a entorns de producció.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Hi ha <strong>%n</strong> aplicació que no té disponible cap versió compatible amb aquesta versió del Nextcloud.","Hi ha <strong>%n</strong> aplicacions que no tenen disponible cap versió compatible amb aquesta versió del Nextcloud."],
    "Update for %1$s to version %2$s is available." : "Hi ha disponible l'actualització a la versió %2$s per a %1$s.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Podeu canviar el canal d'actualitzacions a continuació, que també afecta la pàgina d'administració d'aplicacions. Per exemple, després de canviar al canal beta, se us oferiran actualitzacions d'aplicacions beta a la pàgina d'administració d'aplicacions.",
    "Update channel:" : "Canal d'actualitzacions:"
},
"nplurals=2; plural=(n != 1);");

==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/updatenotification/l10n/ca.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} ja està disponible. Obteniu més informació sobre com aplicar l'actualització.",
    "Channel updated" : "S'ha actualitzat el canal",
    "Web updater is disabled" : "L'actualitzador web està inhabilitat",
    "Update notifications" : "Notificacions d'actualització",
    "The update server could not be reached since %d days to check for new updates." : "No s'ha pogut accedir al servidor d'actualitzacions des de fa %d dies per a comprovar si hi ha actualitzacions noves.",
    "Please check the Nextcloud and server log files for errors." : "Consulteu els fitxers de registre del servidor i del Nextcloud per a detectar errors.",
    "Update to %1$s is available." : "Hi ha disponible l'actualització a %1$s.",
    "Update to {serverAndVersion} is available." : "Hi ha disponible l'actualització a {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Hi ha disponible l'actualització a la versió %s per a {app}.",
    "Update notification" : "Notificació d'actualització",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Mostra les notificacions d'actualització del Nextcloud i proporciona l'SSO de l'actualitzador.",
    "Update" : "Actualització",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versió que esteu executant ja no es manté. Assegureu-vos d’actualitzar com més aviat millor a una versió admesa.",
    "Apps missing compatible version" : "Aplicacions sense cap versió compatible",
    "View in store" : "Mostra-ho a la botiga",
    "Apps with compatible version" : "Aplicacions amb una versió compatible",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Tingueu en compte que no es recomana l'actualitzador web amb més de 100 usuaris. Utilitzeu l'actualitzador de la línia d'ordres.",
    "Open updater" : "Obre l'actualitzador",
    "Download now" : "Baixa-ho ara",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "L'actualitzador web està inhabilitat. Utilitzeu l'actualitzador de línia d'ordres o el mecanisme d'actualització adequat per al vostre mètode d'instal·lació (p. ex., Docker pull) per a actualitzar.",
    "What's new?" : "Quines novetats hi ha?",
    "View changelog" : "Mostra el registre de canvis",
    "The update check is not yet finished. Please refresh the page." : "La comprovació d'actualitzacions encara no ha finalitzat. Actualitzeu la pàgina.",
    "Your version is up to date." : "Teniu la versió més recent.",
    "A non-default update server is in use to be checked for updates:" : "S'utilitza un servidor d'actualitzacions diferent del servidor per defecte per a comprovar si hi ha actualitzacions:",
    "Update channel" : "Canal d'actualitzacions",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Canviar de canal d'actualitzacions també afecta la pàgina d'administració d'aplicacions. Per exemple, després de canviar al canal beta, se us oferiran actualitzacions d'aplicacions beta a la pàgina d'administració d'aplicacions.",
    "Current update channel:" : "Canal d'actualitzacions actual:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre podeu actualitzar a una versió més recent, però no podeu tornar mai a una versió anterior més estable.",
    "Notify members of the following groups about available updates:" : "Notifica els membres dels grups següents sobre les actualitzacions disponibles:",
    "No groups" : "No hi ha cap grup",
    "Only notifications for app updates are available." : "Només hi ha disponibles notificacions per a actualitzacions d'aplicacions.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal d'actualitzacions seleccionat deixa obsoletes les notificacions específiques del servidor.",
    "The selected update channel does not support updates of the server." : "El canal d'actualitzacions seleccionat no admet les actualitzacions del servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hi ha disponible una nova versió: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Tingueu en compte que, després d'una versió nova, només es mostrarà l'actualització després de la primera versió menor o més endavant. Distribuïm les versions noves de manera repartida en el temps als nostres usuaris i, de vegades, ometem una versió si hi trobem problemes. Obteniu més informació sobre les actualitzacions i els canals de versions a {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Darrera comprovació: {lastCheckedDate} - Obre el registre de canvis",
    "Checking apps for compatible versions" : "S'està comprovant si hi ha versions compatibles de les aplicacions",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Assegureu-vos que el fitxer config.php no defineixi <samp>appstoreenabled</samp> com a fals.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No s'ha pogut establir la connexió a la botiga d'aplicacions o no s'ha retornat cap actualització. Cerqueu les actualitzacions manualment o assegureu-vos que el servidor tingui accés a Internet i que es pugui connectar a la botiga d'aplicacions.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Totes</strong> les aplicacions tenen una versió compatible amb aquesta versió del Nextcloud.",
    "Enterprise" : "Empresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Per a ús empresarial. Proporciona sempre els pedaços més recents, però no s'actualitzarà immediatament a la versió principal següent. Aquesta actualització es produeix quan Nextcloud GmbH ha fet proves i millores addicionals per a implementacions a gran escala i crítiques. Aquest canal només està disponible per als clients i proporciona el paquet Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versió estable més recent. És adequada per a un ús normal i sempre s'actualitzarà a la versió principal més recent.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versió preliminar només per a provar característiques noves, no per a entorns de producció.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Hi ha <strong>%n</strong> aplicació que no té disponible cap versió compatible amb aquesta versió del Nextcloud.","Hi ha <strong>%n</strong> aplicacions que no tenen disponible cap versió compatible amb aquesta versió del Nextcloud."],
    "Please use the command line updater to update." : "Utilitzeu l'actualitzador de la línia d'ordres per a aplicar l'actualització.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Podeu canviar el canal d'actualitzacions a continuació, que també afecta la pàgina d'administració d'aplicacions. Per exemple, després de canviar al canal beta, se us oferiran actualitzacions d'aplicacions beta a la pàgina d'administració d'aplicacions.",
    "Update channel:" : "Canal d'actualitzacions:",
    "Checked on {lastCheckedDate}" : "Darrera comprovació: {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
